==> gst-plugins-good-0.10.31.tar.xz: gst-plugins-good-0.10.31/gst/rtp/gstrtpgsmpay.h <==
/* GStreamer
 * Copyright (C) <1999> Erik Walthinsen <omega@cse.ogi.edu>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef __GST_RTP_GSM_PAY_H__
#define __GST_RTP_GSM_PAY_H__

#include <gst/gst.h>
#include <gst/rtp/gstbasertppayload.h>

G_BEGIN_DECLS

typedef struct _GstRTPGSMPay GstRTPGSMPay;
typedef struct _GstRTPGSMPayClass GstRTPGSMPayClass;

#define GST_TYPE_RTP_GSM_PAY \
  (gst_rtp_gsm_pay_get_type())
#define GST_RTP_GSM_PAY(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_RTP_GSM_PAY,GstRTPGSMPay))
#define GST_RTP_GSM_PAY_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_RTP_GSM_PAY,GstRTPGSMPayClass))
#define GST_IS_RTP_GSM_PAY(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_RTP_GSM_PAY))
#define GST_IS_RTP_GSM_PAY_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_RTP_GSM_PAY))

struct _GstRTPGSMPay
{
  GstBaseRTPPayload payload;
};

struct _GstRTPGSMPayClass
{
  GstBaseRTPPayloadClass parent_class;
};

GType gst_rtp_gsm_pay_get_type (void);

gboolean gst_rtp_gsm_pay_plugin_init (GstPlugin * plugin);

G_END_DECLS

#endif /* __GST_RTP_GSM_PAY_H__ */

==> gst-plugins-good1.0_1.0.5.orig.tar.xz: gst-plugins-good-1.0.5/gst/rtp/gstrtpgsmpay.h <==
/* GStreamer
 * Copyright (C) <1999> Erik Walthinsen <omega@cse.ogi.edu>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef __GST_RTP_GSM_PAY_H__
#define __GST_RTP_GSM_PAY_H__

#include <gst/gst.h>
#include <gst/rtp/gstrtpbasepayload.h>

G_BEGIN_DECLS

typedef struct _GstRTPGSMPay GstRTPGSMPay;
typedef struct _GstRTPGSMPayClass GstRTPGSMPayClass;

#define GST_TYPE_RTP_GSM_PAY \
  (gst_rtp_gsm_pay_get_type())
#define GST_RTP_GSM_PAY(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_RTP_GSM_PAY,GstRTPGSMPay))
#define GST_RTP_GSM_PAY_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_RTP_GSM_PAY,GstRTPGSMPayClass))
#define GST_IS_RTP_GSM_PAY(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_RTP_GSM_PAY))
#define GST_IS_RTP_GSM_PAY_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_RTP_GSM_PAY))

struct _GstRTPGSMPay
{
  GstRTPBasePayload payload;
};

struct _GstRTPGSMPayClass
{
  GstRTPBasePayloadClass parent_class;
};

GType gst_rtp_gsm_pay_get_type (void);

gboolean gst_rtp_gsm_pay_plugin_init (GstPlugin * plugin);

G_END_DECLS

#endif /* __GST_RTP_GSM_PAY_H__ */
